#[non_exhaustive]pub enum CudaEncodeFallbackReason {
DeviceUnavailable,
DeviceRouteIncomplete,
}Expand description
Reason an Auto lossless encode completed on the CPU.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CUDA support was not compiled or no usable CUDA runtime/device was found.
DeviceRouteIncomplete
CUDA was available, but it did not implement every stage required by the request.