#[non_exhaustive]pub enum Error {
Decode(J2kError),
NativeDecode {
context: &'static str,
source: NativeBackendError,
},
Buffer(BufferError),
HostAllocationFailed {
bytes: usize,
what: &'static str,
},
HostAllocationTooLarge {
requested: usize,
cap: usize,
what: &'static str,
},
HtJobChunkPlan(HtGpuJobChunkPlanError),
UnsupportedBackend {
request: BackendRequest,
},
UnsupportedCudaRequest {
reason: &'static str,
},
CudaUnavailable,
CudaRuntime {
source: CudaError,
},
CudaTier1JobFailed {
source_index: usize,
original_job_index: usize,
source: CudaError,
},
CudaCleanupFailed {
primary: Box<Error>,
cleanup: Box<Error>,
},
}Expand description
Error returned by the CUDA JPEG 2000 adapter.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Decode(J2kError)
CPU JPEG 2000 decode failed.
NativeDecode
Native decoder failure produced while preparing CUDA-resident work.
Fields
source: NativeBackendErrorConcrete native decoder failure.
Buffer(BufferError)
Caller-owned output buffers were invalid.
HostAllocationFailed
A host-side allocation needed by the adapter could not be reserved.
Fields
HostAllocationTooLarge
Allocator-reported host capacity exceeds the codec phase budget.
Fields
HtJobChunkPlan(HtGpuJobChunkPlanError)
Bounded HTJ2K GPU job planning rejected one source job.
UnsupportedBackend
Backend request is unsupported by this adapter.
Fields
request: BackendRequestRequested backend.
UnsupportedCudaRequest
CUDA request is unsupported by the strict CUDA adapter contract.
CUDA runtime or device is unavailable.
CudaRuntime
CUDA runtime returned an error.
Fields
CudaTier1JobFailed
A classic JPEG 2000 or HTJ2K tier-1 descriptor failed during GPU execution.
Fields
CudaCleanupFailed
A CUDA operation failed and the required resource cleanup also failed.